# alacorder beta 7.3.4

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/sbrobson959/alacorder/main?labpath=index.ipynb)
[<img data-canonical-src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab" src="https://camo.githubusercontent.com/84f0493939e0c4de4e6dbe113251b4bfb5353e57134ffd9fcab6b8714514d4d1/68747470733a2f2f636f6c61622e72657365617263682e676f6f676c652e636f6d2f6173736574732f636f6c61622d62616467652e737667">](https://colab.research.google.com/github/sbrobson959/alacorder/blob/main/index.ipynb)


### Alacorder processes case detail PDFs into data tables suitable for research purposes. Alacorder also generates compressed text archives from the source PDFs to speed future data collection from the same set of cases.

## Installation

**Alacorder can run on most devices. If your device can run Python 3.7 or later, it can run alacorder.**
* To install on Windows, open Command Prompt and enter `pip install alacorder`. 
    * To start the interface, enter `python -m alacorder` or `python3 -m alacorder`.
* On Mac, open the Terminal and enter `pip3 install alacorder` then `python3 -m alacorder`.
    * To start the interface, enter `python3 -m alacorder` or `python -m alacorder`.

#### Install the interactive version on your desktop by installing [Anaconda Distribution](https://www.anaconda.com/) and opening "Jupyter Lab." Open `index.ipynb` in Jupyter then run the `pip` command below. Running the `pip` command below will also update your copy of `alacorder` to the latest version automatically.

<sup> [GitHub](https://github.com/sbrobson959/alacorder)  | [PyPI](https://pypi.org/project/alacorder/)     | [Report an issue](mailto:sbrobson@crimson.ua.edu) </sup>

<sup>© 2023 Sam Robson</sup>
